# H&M-Scraper-Project

[![PyPI](https://img.shields.io/pypi/v/h_and_m_scraper.svg)](https://pypi.org/project/h-and-m-scraper/) [![Build Status](https://github.com/IvanYingX/Urbanoutfitters-Scraper-Project/workflows/Python%20Testing/badge.svg)](https://github.com/IvanYingX/Urbanoutfitters-Scraper-Project/actions/workflows/python-test.yml) [![LICENSE](https://img.shields.io/badge/license-MIT-428f7e.svg)](https://github.com/IvanYingX/Urbanoutfitters-Scraper-Project/blob/main/LICENSE) [![Docker](https://badgen.net/badge/icon/docker?icon=docker&label)](https://hub.docker.com/r/danbouchard/handm_scraper)

A package created to scrape the H&M website for data and images for both mens and womens clothing.